@@ -228,15 +228,12 @@ def read_aircall_calls(token, api_key, #mandatory
 
 ## hubspot deals
 
-def read_hubspot_deals(API_KEY, 
-                        
-                        #optional input
-                        n_days = 7):
+def read_hubspot_deals(API_KEY, start_date, end_date):
     
     
     from askdata.integrations import hubspot_api
     
-    deals_all_fiels = hubspot_api.get_hubspot_deals_all_fields(API_KEY, n_days)
+    deals_all_fiels = hubspot_api.get_hubspot_deals_all_fields(API_KEY, start_date, end_date)
     
     return deals_all_fiels
  
@@ -244,14 +241,11 @@ def read_hubspot_deals(API_KEY,
     
 ## hubspot contact
 
-def read_hubspot_contact(API_KEY,
-                         
-                         #optional input
-                         n_days = 7):
+def read_hubspot_contact(API_KEY, start_date):
     
     from askdata.integrations import hubspot_api
     
-    hubspot_contact = hubspot_api.get_hubspot_contact(API_KEY, n_days)
+    hubspot_contact = hubspot_api.get_hubspot_contact(API_KEY, start_date)
     
     return hubspot_contact
                          
